<?php
/**
 * Item Model
 *
 * @package         Content Templater
 * @version         3.2.5
 *
 * @author          Peter van Westen <peter@nonumber.nl>
 * @link            http://www.nonumber.nl
 * @copyright       Copyright © 2012 NoNumber All Rights Reserved
 * @license         http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 */

defined('_JEXEC') or die;

// Import MODEL object class
jimport('joomla.application.component.model');

require_once JPATH_PLUGINS . '/system/nnframework/helpers/parameters.php';

/**
 * Item Model
 */
class ContentTemplaterModelItem extends JModel
{
	/**
	 * Item id
	 *
	 * @var int
	 */
	var $_id = null;

	/**
	 * Item data
	 *
	 * @var object
	 */
	var $_data = null;

	/**
	 * Item params
	 *
	 * @var object
	 */
	var $_params = null;

	/**
	 * Config
	 *
	 * @var object
	 */
	var $_config = null;

	/**
	 * Custom Constructor
	 */
	function __construct()
	{
		parent::__construct();

		$array = JRequest::getVar('cid', 0, '', 'array');

		$this->setId((int) $array['0']);
	}

	/**
	 * Method to set the list identifier
	 *
	 * @access    public
	 *
	 * @param    int list identifier
	 */
	function setId($id)
	{
		// Set list id and wipe data
		$this->_id = $id;
		$this->_data = null;
	}

	/**
	 * Method to get a list
	 */
	function &getData($getxml = 1, $params = false, $getdefaults = 0)
	{
		$this->_initData();

		// Load the list data
		if ($params) {
			$this->_params = $params;
			unset($params);
		} else {
			$this->_loadParams();
		}

		$this->updateOldParams($this->_params->params, $this->_params->id);

		$parameters = NNParameters::getInstance();
		$xmlfile = JPATH_ADMINISTRATOR . '/components/com_contenttemplater/item_params.xml';

		$this->_data = $parameters->getParams($this->_params->params, $xmlfile, 1);
		foreach ($this->_params as $key => $val) {
			if ($key != 'params' && !is_array($val) && !is_object($val)) {
				if ($key == 'content') {
					$this->_data->$key = html_entity_decode($val, ENT_COMPAT, 'UTF-8');
				} else {
					$this->_data->$key = $val;
				}
			}
		}

		$this->stripSlashesFromObject($this->_data);

		if ($getxml) {
			$registry = new JRegistry;
			$registry->loadObject($this->_data);
			$params = $registry->toString();

			$this->_data->_xml = new JParameter($params, $xmlfile);
		}
		if ($getdefaults) {
			$this->defaults = $parameters->getParams('', $xmlfile);
		}

		return $this->_data;
	}

	/**
	 * Method to checkout/lock the list
	 *
	 * @access    public
	 *
	 * @param    int    $uid    User ID of the user checking the article out
	 *
	 * @return    boolean    True on success
	 */
	function checkout($uid = null)
	{
		if ($this->_id) {
			// Make sure we have a user id to checkout the article with
			if (is_null($uid)) {
				$user = JFactory::getUser();
				$uid = $user->get('id');
			}
			// Lets get to it and checkout the thing...
			$list = $this->getTable();

			if (!$list->checkout($uid, $this->_id)) {
				$this->setError($this->_db->getErrorMsg());
				return 0;
			}
			return 1;
		}
		return 0;
	}

	/**
	 * Method to checkin/unlock the list
	 *
	 * @access    public
	 * @return    boolean    True on success
	 */
	function checkin()
	{
		if ($this->_id) {
			$list = $this->getTable();
			if (!$list->checkin($this->_id)) {
				$this->setError($this->_db->getErrorMsg());
				return 0;
			}
			return 1;
		}
		return 0;
	}

	/**
	 * Tests if list is checked out
	 *
	 * @access    public
	 *
	 * @param    int    A user id
	 *
	 * @return    boolean    True if checked out
	 */
	function isCheckedOut($uid = 0)
	{
		if ($uid) {
			return ($this->_data->checked_out && $this->_data->checked_out != $uid);
		} else {
			return $this->_data->checked_out;
		}
	}

	/**
	 * Method to load content list data
	 *
	 * @access    private
	 * @return    boolean    True on success
	 */
	function _loadParams()
	{
		// Lets load the content if it doesn't already exist
		if (!$this->_params) {
			$query = 'SELECT * FROM #__contenttemplater WHERE id = ' . $this->_id;
			$this->_db->setQuery($query);
			$this->_params = $this->_db->loadObject();
		}
		if (!$this->_params) {
			$this->_params = $this->_data;
			$this->_params->params = null;
		}
		if (!$this->_config) {
			$parameters = NNParameters::getInstance();
			$this->_config = $parameters->getComponentParams('contenttemplater');
		}
	}

	/**
	 * Method to initialise the list data
	 *
	 * @access    private
	 * @return    boolean    True on success
	 */
	function _initData()
	{
		// Lets load the content if it doesn't already exist
		if (!$this->_data) {
			$detail = new stdClass;
			$detail->id = $this->_id;
			$detail->published = 1;
			$detail->checked_out = 0;
			$detail->checked_out_time = 0;
			$detail->ordering = 0;
			$this->_data = $detail;
		}
	}

	/**
	 * Method to store the data
	 *
	 * @access    public
	 * @return    boolean    True on success
	 */
	function store($data)
	{
		// Load table class from com_contenttemplater/tables/item.php
		$row = $this->getTable();

		// Take all table row params from the params string
		// put them in the $data
		// and remove them from the params string
		$registry = new JRegistry;
		$registry->loadINI($data['params']);
		$params = $registry->toArray();

		foreach ($row as $key => $val) {
			if (isset($params[$key])) {
				$data[$key] = $params[$key];
				unset($params[$key]);
			}
		}

		$registry = new JRegistry;
		$registry->loadArray($params);
		$data['params'] = $registry->toString();

		// Bind the form fields to the list table
		if (!$row->bind($data)) {
			$this->setError($this->_db->getErrorMsg());
			return $this->_errors;
		}

		// Make sure the list table is valid
		// JTable return always true but there is space to put
		// our custom check method
		if (!$row->check()) {
			$this->setError($this->_db->getErrorMsg());
			return $this->_errors;
		}

		// Store the list table to the database
		if (!$row->store()) {
			$this->setError($this->_db->getErrorMsg());
			return $this->_errors;
		}

		$this->_id = $row->id;
		return 1;
	}

	/**
	 * Method to copy an item
	 *
	 * @access    public
	 * @return    boolean    True on success
	 */
	function copy($cid = array())
	{
		foreach ($cid as $id) {
			$this->_data = null;
			$this->_params = null;
			$this->_id = $id;
			$this->getData();
			$data = $this->_data;

			$data->id = 0;
			$data->published = 0;
			$data->name = JText::sprintf('NN_COPY_OF', $data->name);

			$registry = new JRegistry;
			$registry->loadObject($data);
			$params = array();
			$params['params'] = addslashes($registry->toString());

			$this->store($params);
		}
		return 1;
	}

	/**
	 * Method to remove an item
	 *
	 * @access    public
	 * @return    boolean    True on success
	 */
	function delete($cid = array())
	{
		if (count($cid)) {
			$cids = implode(',', $cid);
			$query = 'DELETE FROM #__contenttemplater WHERE id IN ( ' . $cids . ' )';
			$this->_db->setQuery($query);
			if (!$this->_db->query()) {
				$this->setError($this->_db->getErrorMsg());
				return 0;
			}
		}
		return 1;
	}

	/**
	 * Method to (un)publish a list
	 *
	 * @access    public
	 * @return    boolean    True on success
	 */
	function publish($cid = array(), $publish = 1)
	{
		$user = JFactory::getUser();

		if (count($cid)) {
			$cids = implode(',', $cid);

			$query = 'UPDATE #__contenttemplater'
				. ' SET published = ' . intval($publish)
				. ' WHERE id IN ( ' . $cids . ' )'
				. ' AND ( checked_out = 0 OR ( checked_out = ' . $user->get('id') . ' ) )';
			$this->_db->setQuery($query);
			if (!$this->_db->query()) {
				$this->setError($this->_db->getErrorMsg());
				return 0;
			}
		}
		return 1;
	}

	/**
	 * Method to move a item
	 *
	 * @access    public
	 * @return    boolean    True on success
	 */
	function saveorder($cid = array(), $order)
	{
		$query = ' SELECT * FROM #__contenttemplater';
		$itemlist = $this->_getList($query, $this->getState('limitstart'), $this->getState('limit'));

		$order_list = array();
		foreach ($cid as $i => $id) {
			$order_list[$id] = ($order[$i] * 100000) - $i;
		}

		$order_array = array();
		foreach ($itemlist as $item) {
			if (isset($order_list[$item->id])) {
				$order = $order_list[$item->id];
			} else {
				$order = $item->ordering * 100000;
			}
			$order_array[$item->id] = $order + ($item->id / 100000);
		}

		asort($order_array);
		$order_array = array_keys($order_array);

		// Load table class from com_contenttemplater/tables/item.php
		$row = $this->getTable();

		// update ordering values
		$count = count($order_array);
		for ($i = 0; $i < $count; $i++) {
			$row->load((int) $order_array[$i]);
			if ($row->ordering != $i + 1) {
				$row->ordering = $i + 1;
				if (!$row->store()) {
					$this->setError($this->_db->getErrorMsg());
					return 0;
				}
			}
		}
		return 1;
	}

	/**
	 * Method to move a list
	 *
	 * @access    public
	 * @return    boolean    True on success
	 */
	function move($direction)
	{
		// Load table class from com_contenttemplater/tables/item.php
		$row = $this->getTable();
		// we need to pass here id of list detail
		if (!$row->load($this->_id)) {
			$this->setError($this->_db->getErrorMsg());
			return 0;
		}

		// call move method of JTABLE
		// first parameter: direction [up/down]
		// second parameter: condition
		if (!$row->move($direction, ' published >= 0 ')) {
			$this->setError($this->_db->getErrorMsg());
			return 0;
		}
		return 1;
	}

	function stripSlashesFromObject(&$obj, $exclude = array())
	{
		foreach ($obj as $key => $val) {
			if (is_string($val) && !in_array($key, $exclude)) {
				$obj->$key = stripslashes($val);
			}
		}
	}

	function updateOldParams(&$params, $id)
	{
		$p = $params;

		$p = str_replace('content_title=', 'title=', $p);
		$p = str_replace('content_alias=', 'alias=', $p);
		$p = str_replace("\n" . 'button_assignto_', "\n" . 'assignto_', $p);

		if ($id && $p != $params) {
			$query = 'UPDATE #__contenttemplater'
				. ' SET params = ' . $this->_db->quote($p)
				. ' WHERE id = ' . (int) $id;
			$this->_db->setQuery($query);
			$this->_db->query();
		}

		$params = $p;
	}

	function replaceVars(&$str)
	{
		if (!(strpos($str, '[[user:') === false)) {
			if (preg_match_all('#\[\[user\:([^\]]+)\]\]#', $str, $matches, PREG_SET_ORDER) > 0) {
				$user = JFactory::getUser();
				$contact = null;
				foreach ($matches as $match) {
					if ($match['1'] == 'password' || $match['1']['0'] == '_') {
						$str = str_replace($match['0'], '', $str);
					} else if (isset($user->{$match['1']})) {
						$str = str_replace($match['0'], $user->{$match['1']}, $str);
					} else {
						if (!$contact) {
							$db = JFactory::getDBO();
							$query = "SELECT * FROM #__" . $this->_config->contact_table . "
								WHERE user_id = " . (int) $user->id . "
								LIMIT 1";
							$db->setQuery($query);
							$contact = $db->loadObject();
						}
						if (isset($contact->{$match['1']})) {
							$str = str_replace($match['0'], $contact->{$match['1']}, $str);
						} else {
							$str = str_replace($match['0'], '', $str);
						}
					}
				}
			}
		}
		if (!(strpos($str, '[[date:') === false)) {
			if (preg_match_all('#\[\[date\:([^\]]+)\]\]#', $str, $matches, PREG_SET_ORDER) > 0) {
				require_once JPATH_PLUGINS . '/system/nnframework/helpers/functions.php';
				foreach ($matches as $match) {
					if ($match['1'] && strpos($match['1'], '%') === false) {
						$match['1'] = NNText::dateToStrftimeFormat($match['1']);
					}
					$replace = JHtml::_('date', time(), $match['1']);
					$str = str_replace($match['0'], $replace, $str);
				}
			}
		}
		if (!(strpos($str, '[[random:') === false)) {
			while (preg_match('#\[\[random\:([0-9]+)-([0-9]+)\]\]#', $str, $match)) {
				$search = '#' . preg_quote($match['0'], "#") . '#';
				$replace = rand((int) $match['1'], (int) $match['2']);
				$str = preg_replace($search, $replace, $str, 1);
			}
		}
	}
}

if (!function_exists('property_exists')) {
	function property_exists($class, $property)
	{
		if (is_object($class)) {
			$vars = get_object_vars($class);
		} else {
			$vars = get_class_vars($class);
		}
		return array_key_exists($property, $vars);
	}
}