<?php
/**
 * Item Table
 *
 * @package         Content Templater
 * @version         3.2.5
 *
 * @author          Peter van Westen <peter@nonumber.nl>
 * @link            http://www.nonumber.nl
 * @copyright       Copyright © 2012 NoNumber All Rights Reserved
 * @license         http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 */

defined('_JEXEC') or die;

/**
 * Item Table
 */
class TableItem extends JTable
{
	/**
	 * Primary Key
	 *
	 * @var int
	 */
	var $id = null;

	/**
	 * @var string
	 */
	var $name = null;

	/**
	 * @var string
	 */
	var $description = null;

	/**
	 * @var string
	 */
	var $content = null;

	/**
	 * @var string
	 */
	var $params = null;

	/**
	 * @var int
	 */
	var $published = null;

	/**
	 * @var boolean
	 */
	var $checked_out = 0;

	/**
	 * @var time
	 */
	var $checked_out_time = 0;

	/**
	 * @var int
	 */
	var $ordering = null;

	/**
	 * Constructor
	 */
	function TableItem(&$db)
	{
		parent::__construct($db->getPrefix() . 'contenttemplater', 'id', $db);
	}

	/**
	 * Overloaded bind function
	 *
	 * @acces public
	 *
	 * @param array $hash named array
	 *
	 * @return null|string    null is operation was satisfactory, otherwise returns an error
	 * @see   JTable:bind
	 */

	function bind($array, $ignore = '')
	{
		if (key_exists('params', $array) && is_array($array['params'])) {
			$registry = new JRegistry;
			$registry->loadArray($array['params']);
			$array['params'] = $registry->toString();
		}

		return parent::bind($array, $ignore);
	}

	/**
	 * Overloaded check method to ensure data integrity
	 *
	 * @access public
	 * @return boolean True on success
	 */
	function check()
	{
		/** check for valid name */
		if (trim($this->name) == '') {
			$this->_error = JText::_('CT_THE_ITEM_MUST_HAVE_A_NAME');
			return 0;
		}

		return 1;
	}
}