<?php
/**
 * List View
 *
 * @package         Content Templater
 * @version         3.2.5
 *
 * @author          Peter van Westen <peter@nonumber.nl>
 * @link            http://www.nonumber.nl
 * @copyright       Copyright © 2012 NoNumber All Rights Reserved
 * @license         http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 */

defined('_JEXEC') or die;

// Import VIEW object class
jimport('joomla.application.component.view');

/**
 * List View
 */
class ContentTemplaterViewList extends JView
{
	/**
	 * Custom Constructor
	 */
	function __construct($config = array())
	{
		/** set up global variable for sorting etc
		 * $context is used in VIEW abd in MODEL
		 **/
		global $context;
		$context = 'list.list.';

		parent::__construct($config);
	}

	/**
	 * Display the view
	 * take data from MODEL and put them into
	 * reference variables
	 */

	function display($tpl = null)
	{
		$app = JFactory::getApplication();
		$viewLayout = JRequest::getCmd('layout', 'default');

		$comp_name = 'contenttemplater';
		$config = JComponentHelper::getParams('com_' . $comp_name);

		require_once JPATH_PLUGINS . '/system/nnframework/helpers/versions.php';

		$document = JFactory::getDocument();
		$version = NoNumberVersions::getXMLVersion(null, null, null, 1);
		$document->addStyleSheet(JURI::root(true) . '/plugins/system/nnframework/css/style.css' . $version);
		$version = NoNumberVersions::getXMLVersion($comp_name, 'component', 1, 1);
		$document->addStyleSheet(JURI::root(true) . '/administrator/components/com_' . $comp_name . '/css/style.css' . $version);

		if ($viewLayout == 'import') {
			// Set document title
			$document->setTitle(JText::_('CONTENT_TEMPLATER') . ' : ' . JText::_('NN_IMPORT_ITEMS'));
			// Set ToolBar title
			JToolBarHelper::title(JText::_('NN_IMPORT_ITEMS'), $comp_name . '.png');
			// Set toolbar items for the page
			JToolBarHelper::back();
		} else {
			// Set document title
			$document->setTitle(JText::_('CONTENT_TEMPLATER') . ' : ' . JText::_('NN_LIST'));
			// Set ToolBar title
			JToolBarHelper::title(JText::_('NN_LIST'), $comp_name . '.png');
			// Set toolbar items for the page
			JToolBarHelper::addNewX();
			JToolBarHelper::customX('copy', 'copy.png', 'copy.png', 'Copy');
			JToolBarHelper::editListX();
			JToolBarHelper::divider();
			JToolBarHelper::publishList();
			JToolBarHelper::unpublishList();
			JToolBarHelper::divider();
			JToolBarHelper::customX('export', 'export.png', 'export.png', 'NN_EXPORT');
			JToolBarHelper::custom('import', 'import.png', 'import.png', 'NN_IMPORT', false, false);
			JToolBarHelper::divider();
			JToolBarHelper::deleteList('VALIDDELETEITEMS');
			JToolBarHelper::divider();
			JToolBarHelper::preferences('com_' . $comp_name, '550');

			$bar = JToolBar::getInstance('toolbar');
			JToolBarHelper::divider();
			$bar->appendButton('Popup', 'help', 'Help', 'http://www.nonumber.nl/' . $comp_name . '?ml=1', 'window.getSize().size.x-100', 'window.getSize().size.y-100');
		}

		// Set ToolBar title
		$uri = JFactory::getURI();

		// get filter options
		$filter_order = $app->getUserStateFromRequest($comp_name . '.filter_order', 'filter_order', 'ordering', 'cmd');
		$filter_order_Dir = $app->getUserStateFromRequest($comp_name . '.filter_order_Dir', 'filter_order_Dir', '', 'word');
		$filter_state = $app->getUserStateFromRequest($comp_name . '.filter_state', 'filter_state', $config->get('state', ''), 'word');
		$search = $app->getUserStateFromRequest($comp_name . '.search', 'search', '', 'string');
		$search = JString::strtolower($search);
		$limit = $app->getUserStateFromRequest($comp_name . '.limit', 'limit', $app->getCfg('list_limit'), 'int');
		$limitstart = JRequest::getCmd('limitstart');

		// remember the actual order and column
		$lists['order'] = $filter_order;
		$lists['order_Dir'] = $filter_order_Dir;
		$lists['state'] = JHtml::_('grid.state', $filter_state);
		$lists['search'] = $search;

		$this->_models['list']->setState('state', $filter_state);
		$this->_models['list']->setState('limit', $limit);
		$this->_models['list']->setState('limitstart', $limitstart);
		$this->_models['list']->setState('search', $search);

		$items = $this->get('AllParams');

		$pageNav = $this->get('Pagination');

		// save a reference into view
		$this->assignRef('user', JFactory::getUser());
		$this->assignRef('lists', $lists);
		$this->assignRef('items', $items);
		$this->assignRef('pagination', $pageNav);
		$this->assignRef('request_url', $uri->toString());

		// call parent display
		parent::display($tpl);
	}

	function maxlen($string = '', $maxlen = 60)
	{
		if (strlen($string) > $maxlen) {
			$string = substr($string, 0, $maxlen - 3) . '...';
		}
		return $string;
	}
}