<?php
/**
 * Item View
 *
 * @package         ReReplacer
 * @version         4.2.1
 *
 * @author          Peter van Westen <peter@nonumber.nl>
 * @link            http://www.nonumber.nl
 * @copyright       Copyright © 2012 NoNumber All Rights Reserved
 * @license         http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 */

defined('_JEXEC') or die;

jimport('joomla.application.component.view');

/**
 * Item View
 */
class ReReplacerViewItem extends JView
{
	/**
	 * Display the view
	 */
	function display($tpl = null)
	{
		$app = JFactory::getApplication();
		$option = JRequest::getCmd('option');

		$comp_name = 'rereplacer';

		$parameters = NNParameters::getInstance();
		$config = $parameters->getComponentParams($comp_name);

		require_once JPATH_PLUGINS . '/system/nnframework/helpers/versions.php';

		// set document title
		$document = JFactory::getDocument();
		$document->setTitle(JText::_('REREPLACER') . ' : ' . JText::_('NN_ITEM'));
		$version = NoNumberVersions::getXMLVersion(null, null, null, 1);
		$document->addStyleSheet(JURI::root(true) . '/plugins/system/nnframework/css/style.css' . $version);
		$version = NoNumberVersions::getXMLVersion($comp_name, 'component', 1, 1);
		$document->addStyleSheet(JURI::root(true) . '/administrator/components/com_' . $comp_name . '/css/style.css' . $version);

		$uri = JFactory::getURI();
		$user = JFactory::getUser();
		$model = $this->getModel();

		// prepare array
		$lists = array();

		// get the rereplacer
		$detail = $this->get('data');

		// the new record ? Edit or Create?
		$isNew = ($detail->id < 1);

		// fail if checked out not by 'me'
		if ($model->isCheckedOut($user->get('id'))) {
			$msg = JText::sprintf('DESCBEINGEDITTED', JText::_('RR_THE_ITEM'), $detail->descript);
			$app->redirect('index.php?option=' . $option, $msg);
		}

		// Set toolbar items for the page
		$text = $isNew ? JText::_('New') : JText::_('Edit');
		JToolBarHelper::title(JText::_('NN_ITEM') . ': <small><small>[ ' . $text . ' ]</small></small>', $comp_name . '.png');
		JToolBarHelper::custom('apply', 'save-apply.png', 'save-apply.png', 'Save', false);
		JToolBarHelper::custom('save', 'save-close.png', 'save-close.png', 'NN_SAVE_CLOSE', false);
		JToolBarHelper::custom('save2new', 'save-new.png', 'save-new.png', 'NN_SAVE_NEW', false);
		JToolBarHelper::custom('save2copy', 'save-copy.png', 'save-copy.png', 'NN_SAVE_COPY', false);
		JToolBarHelper::cancel('cancel', 'Close');

		$bar = JToolBar::getInstance('toolbar');
		JToolBarHelper::divider();
		$bar->appendButton('Popup', 'help', 'Help', 'http://www.nonumber.nl/' . $comp_name . '?ml=1', 'window.getSize().size.x-100', 'window.getSize().size.y-100');

		// Edit or Create?
		if (!$isNew) {
			$model->checkout($user->get('id'));
		} else {
			// initialise new record
			$detail->published = 1;
			$detail->order = 0;
		}

		// build the html select list
		$lists['published'] = JHtml::_('select.booleanlist', 'published', 'class="inputbox"', $detail->published);

		// Clear rereplacer HTML data
		jimport('joomla.filter.filteroutput');
		JFilterOutput::objectHTMLSafe($detail, ENT_QUOTES);

		$this->assignRef('lists', $lists);
		$this->assignRef('detail', $detail);
		$this->assignRef('request_url', $uri->toString());
		$this->assignRef('config', $config);

		parent::display($tpl);
	}
}