<?php
/**
 * List View
 *
 * @package         ReReplacer
 * @version         4.2.1
 *
 * @author          Peter van Westen <peter@nonumber.nl>
 * @link            http://www.nonumber.nl
 * @copyright       Copyright © 2012 NoNumber All Rights Reserved
 * @license         http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 */

defined('_JEXEC') or die;

jimport('joomla.application.component.view');

/**
 * List View
 */
class ReReplacerViewList extends JView
{
	/**
	 * Custom Constructor
	 */
	function __construct($config = array())
	{
		/** set up global variable for sorting etc
		 * $context is used in VIEW abd in MODEL
		 **/
		global $context;
		$context = 'list.list.';

		parent::__construct($config);
	}

	/**
	 * Display the view
	 * take data from MODEL and put them into
	 * reference variables
	 */

	function display($tpl = null)
	{
		$app = JFactory::getApplication();
		$viewLayout = JRequest::getCmd('layout', 'default');

		$comp_name = 'rereplacer';
		$config = JComponentHelper::getParams('com_' . $comp_name);

		require_once JPATH_PLUGINS . '/system/nnframework/helpers/versions.php';

		$document = JFactory::getDocument();
		$version = NoNumberVersions::getXMLVersion(null, null, null, 1);
		$document->addStyleSheet(JURI::root(true) . '/plugins/system/nnframework/css/style.css' . $version);
		$version = NoNumberVersions::getXMLVersion($comp_name, 'component', 1, 1);
		$document->addStyleSheet(JURI::root(true) . '/administrator/components/com_' . $comp_name . '/css/style.css' . $version);

		if ($viewLayout == 'import') {
			// Set document title
			$document->setTitle(JText::_('REREPLACER') . ' : ' . JText::_('NN_IMPORT_ITEMS'));
			// Set ToolBar title
			JToolBarHelper::title(JText::_('NN_IMPORT_ITEMS'), $comp_name . '.png');
			// Set toolbar items for the page
			JToolBarHelper::back();
		} else {
			// Set document title
			$document->setTitle(JText::_('REREPLACER') . ' : ' . JText::_('NN_LIST'));
			// Set ToolBar title
			JToolBarHelper::title(JText::_('NN_LIST'), $comp_name . '.png');
			// Set toolbar items for the page
			JToolBarHelper::addNewX();
			JToolBarHelper::customX('copy', 'copy.png', 'copy.png', 'Copy');
			JToolBarHelper::editListX();
			JToolBarHelper::divider();
			JToolBarHelper::publishList();
			JToolBarHelper::unpublishList();
			JToolBarHelper::divider();
			JToolBarHelper::customX('export', 'export.png', 'export.png', 'NN_EXPORT');
			JToolBarHelper::custom('import', 'import.png', 'import.png', 'NN_IMPORT', false, false);
			JToolBarHelper::divider();
			JToolBarHelper::deleteList('VALIDDELETEITEMS');
			JToolBarHelper::divider();
			JToolBarHelper::preferences('com_' . $comp_name, '240');

			$bar = JToolBar::getInstance('toolbar');
			JToolBarHelper::divider();
			$bar->appendButton('Popup', 'help', 'Help', 'http://www.nonumber.nl/' . $comp_name . '?ml=1', 'window.getSize().size.x-100', 'window.getSize().size.y-100');
		}

		// Set ToolBar title
		$uri = JFactory::getURI();

		// give me ordering from request
		$filter_order = $app->getUserStateFromRequest($comp_name . '.list.filter_order', 'filter_order', 'ordering');
		$filter_order_Dir = $app->getUserStateFromRequest($comp_name . '.list.filter_order_Dir', 'filter_order_Dir', '');

		// get value to show unpublished items in list
		$show_unpublished = $app->getUserStateFromRequest($comp_name . '.list.show_unpublished', 'show_unpublished', $config->get('show_unpublished', 1));
		// get value to show search and replace colomns in list
		$show_searchreplace = $app->getUserStateFromRequest($comp_name . '.list.show_searchreplace', 'show_searchreplace', $config->get('show_searchreplace', 0));

		// remember the actual order and column
		$lists['order'] = $filter_order;
		$lists['order_Dir'] = $filter_order_Dir;

		// Get data from the model
		if ($show_unpublished == 1) {
			$items = $this->get('AllParams');
		} else {
			$items = $this->get('AllPublishedParams');
		}
		$total = $this->get('Total');
		$pagination = $this->get('Pagination');

		// save a reference into view
		$this->assignRef('user', JFactory::getUser());
		$this->assignRef('lists', $lists);
		$this->assignRef('items', $items);
		$this->assignRef('pagination', $pagination);
		$this->assignRef('request_url', $uri->toString());
		$this->assignRef('show_searchreplace', $show_searchreplace);
		$this->assignRef('show_unpublished', $show_unpublished);

		// call parent display
		parent::display($tpl);
	}

	function maxlen($string = '', $maxlen = 60)
	{
		if (JString::strlen($string) > $maxlen) {
			$string = JString::substr($string, 0, $maxlen - 3) . '...';
		}
		return $string;
	}
}