<?php
/**
 * Main Component File
 * Used for the editor button (template xml)
 *
 * @package         Content Templater
 * @version         3.2.5
 *
 * @author          Peter van Westen <peter@nonumber.nl>
 * @link            http://www.nonumber.nl
 * @copyright       Copyright © 2012 NoNumber All Rights Reserved
 * @license         http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 */

defined('_JEXEC') or die;

// Load common functions
require_once JPATH_PLUGINS . '/system/nnframework/helpers/functions.php';

$user = JFactory::getUser();
if ($user->get('guest')) {
	JError::raiseError(403, JText::_("ALERTNOTAUTH"));
}

$app = JFactory::getApplication();
if ($app->isSite()) {
	$params = JComponentHelper::getParams('com_contenttemplater');
	if (!$params->get('enable_frontend', 1)) {
		JError::raiseError(403, JText::_("ALERTNOTAUTH"));
	}
}

$class = new plgButtonContentTemplaterData;
$class->render();
die;

class plgButtonContentTemplaterData
{
	function render()
	{
		header('Content-Type: text/html; charset=utf-8');

		$id = JRequest::getInt('id');

		if (!$id) {
			return;
		}

		$nocontent = JRequest::getInt('nocontent', 0);
		$user = JFactory::getUser();
		$unprotected = ($user->usertype == 'Super Administrator') ? JRequest::getInt('unprotect') : 0;

		require_once JPATH_ADMINISTRATOR . '/components/com_contenttemplater/controllers/item.php';
		require_once JPATH_ADMINISTRATOR . '/components/com_contenttemplater/models/item.php';

		// Create a new class of classname and set the default task: display
		$item = new ContentTemplaterModelItem;
		$item->setId($id);
		$item->getData(0, false, 1);

		$output = array();

		$ignore = array(
			'view_state',
			'id',
			'ordering',
			'name',
			'description',
			'ordering',
			'published',
			'checked_out',
			'checked_out_time',
			'show_url_field_sef',
			'show_url_field',
			'match_method',
			'show_assignments',
			'defaults'
		);

		foreach ($item->_data as $key => $val) {
			if ($val != ''
				&& !isset($output[$key])
				&& !in_array($key, $ignore)
				&& strpos($key, '@') !== 0
				&& strpos($key, 'button_') !== 0
				&& strpos($key, 'load_') !== 0
				&& strpos($key, 'url_') !== 0
				&& strpos($key, 'assignto_') !== 0
			) {
				if ($key == 'content' && $nocontent) {
					continue;
				}
					$default = '';
					if (isset($item->defaults->$key)) {
						$default = $item->defaults->$key;
					}
					if ($val != $default) {
						if (strpos($key, 'params') === 0 && $val == -2) {
							$val = '';
						}
						list($key, $val) = $this->getStr($item, $key, $val, $default);
						$output[$key] = $val;
					}
			}
		}


		$str = implode("\n", $output);
		if (!$unprotected) {
			$str = base64_encode($str);
			$str = wordwrap($str, 80, "\n", 1);
		}
		echo $str;
	}

	function getStr(&$item, $key, $val, $default = '')
	{
		switch ($key) {
			case 'paramsdetailsaccess':
				$default = 1;
				break;
			case 'paramscategories_k2':
				$key = 'catid';
				$default = 0;
				break;
			case 'paramscategories_mr':
			case 'paramscategories_zoo':
				$key = 'categories';
				$default = '';
				break;
		}
		if (is_array($val)) {
			$val = implode(',', $val);
		}
		if ($key != 'content') {
			$this->makeSafeHtml($val);
		}
		$item->replaceVars($val);

		return array($key, '[CT]' . $key . '[CT]' . $default . '[CT]' . $val . '[/CT]');
	}

	function makeSafeHtml(&$str)
	{
		//return html_entity_decode( $str, ENT_QUOTES, 'UTF-8' );
		// TEST IF THIS WORKS ON ALL SETUPS!!!!
		// html_entity_decode GAVE TIMEOUTS ON SOME SETUPS?!?!

		if ($str == '') {
			return;
		}

		static $trans_tbl;

		// replace numeric entities
		$str = preg_replace('~&#x([0-9a-f]+);~ei', 'code2utf(hexdec("\1"))', $str);
		$str = preg_replace('~&#([0-9]+);~e', 'code2utf(\1)', $str);

		// replace literal entities
		if (!isset($trans_tbl)) {
			$trans_tbl = array();

			foreach (get_html_translation_table(HTML_ENTITIES) as $val => $key) {
				$trans_tbl[$key] = utf8_encode($val);
			}
		}

		$str = strtr($str, $trans_tbl);
	}
}